==> affyILM_1.0.0.zip: affyILM/doc/affyILM.R <==
###################################################
### chunk number 1: 
###################################################
library(affy)
library(gcrma)
require(AffymetrixDataTestFiles)


###################################################
### chunk number 2: 
###################################################
require(AffymetrixDataTestFiles)


###################################################
### chunk number 3: 
###################################################
library(affyILM)


###################################################
### chunk number 4: 
###################################################
file1 <- system.file("rawData","FusionSDK_HG-Focus","HG-Focus","2.Calvin","HG-Focus-1-121502.CEL",package="AffymetrixDataTestFiles")


###################################################
### chunk number 5: 
###################################################
result <- ilm(file1) 


###################################################
### chunk number 6: 
###################################################
getIntens(result,"AFFX-r2-Ec-bioD-5_at")


###################################################
### chunk number 7: 
###################################################
plotIntens(result,"AFFX-r2-Ec-bioD-5_at","HG-Focus-1-121502.CEL")


###################################################
### chunk number 8: 
###################################################
file2 <- system.file("rawData","FusionSDK_HG-Focus","HG-Focus","2.Calvin","HG-Focus-2-121502.CEL",package="AffymetrixDataTestFiles")
result2files <- ilm(c(file1,file2),400,12000) 


###################################################
### chunk number 9: 
###################################################
getIntens(result2files,"AFFX-r2-Ec-bioD-5_at")


###################################################
### chunk number 10: 
###################################################
getParams(result2files)


###################################################
### chunk number 11: 
###################################################
getConcs(result2files,"AFFX-r2-Ec-bioD-5_at")


###################################################
### chunk number 12: 
###################################################
res_1 <- result["AFFX-r2-Ec-bioD-5_at"]
res_1
res_2 <- result[c("AFFX-r2-Ec-bioD-5_at","207218_at")]
res_2


###################################################
### chunk number 13: 
###################################################
res2_1 <- result2files["AFFX-r2-Ec-bioD-5_at"]
res2_1
res2_2 <- result2files[c("AFFX-r2-Ec-bioD-5_at","207218_at")]
res2_2


###################################################
### chunk number 14: 
###################################################
plotIntens(result2files,"AFFX-r2-Ec-bioD-5_at","HG-Focus-1-121502.CEL")

==> affyILM_1.2.0.zip: affyILM/doc/affyILM.R <==
###################################################
### chunk number 1: 
###################################################
#line 124 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpFhU4ge/R.INSTALL278e6b04/affyILM/inst/doc/affyILM.Rnw"
library(affy)
library(gcrma)
require(AffymetrixDataTestFiles)


###################################################
### chunk number 2: 
###################################################
#line 132 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpFhU4ge/R.INSTALL278e6b04/affyILM/inst/doc/affyILM.Rnw"
require(AffymetrixDataTestFiles)


###################################################
### chunk number 3: 
###################################################
#line 137 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpFhU4ge/R.INSTALL278e6b04/affyILM/inst/doc/affyILM.Rnw"
library(affyILM)


###################################################
### chunk number 4: 
###################################################
#line 141 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpFhU4ge/R.INSTALL278e6b04/affyILM/inst/doc/affyILM.Rnw"
file1 <- system.file("rawData","FusionSDK_HG-Focus","HG-Focus","2.Calvin","HG-Focus-1-121502.CEL",package="AffymetrixDataTestFiles")


###################################################
### chunk number 5: 
###################################################
#line 146 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpFhU4ge/R.INSTALL278e6b04/affyILM/inst/doc/affyILM.Rnw"
result <- ilm(file1) 


###################################################
### chunk number 6: 
###################################################
#line 161 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpFhU4ge/R.INSTALL278e6b04/affyILM/inst/doc/affyILM.Rnw"
getIntens(result,"AFFX-r2-Ec-bioD-5_at")


###################################################
### chunk number 7: 
###################################################
#line 172 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpFhU4ge/R.INSTALL278e6b04/affyILM/inst/doc/affyILM.Rnw"
plotIntens(result,"AFFX-r2-Ec-bioD-5_at","HG-Focus-1-121502.CEL")


###################################################
### chunk number 8: 
###################################################
#line 184 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpFhU4ge/R.INSTALL278e6b04/affyILM/inst/doc/affyILM.Rnw"
file2 <- system.file("rawData","FusionSDK_HG-Focus","HG-Focus","2.Calvin","HG-Focus-2-121502.CEL",package="AffymetrixDataTestFiles")
result2files <- ilm(c(file1,file2),400,12000) 


###################################################
### chunk number 9: 
###################################################
#line 192 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpFhU4ge/R.INSTALL278e6b04/affyILM/inst/doc/affyILM.Rnw"
getIntens(result2files,"AFFX-r2-Ec-bioD-5_at")


###################################################
### chunk number 10: 
###################################################
#line 204 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpFhU4ge/R.INSTALL278e6b04/affyILM/inst/doc/affyILM.Rnw"
getParams(result2files)


###################################################
### chunk number 11: 
###################################################
#line 209 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpFhU4ge/R.INSTALL278e6b04/affyILM/inst/doc/affyILM.Rnw"
getConcs(result2files,"AFFX-r2-Ec-bioD-5_at")


###################################################
### chunk number 12: 
###################################################
#line 214 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpFhU4ge/R.INSTALL278e6b04/affyILM/inst/doc/affyILM.Rnw"
res_1 <- result["AFFX-r2-Ec-bioD-5_at"]
res_1
res_2 <- result[c("AFFX-r2-Ec-bioD-5_at","207218_at")]
res_2


###################################################
### chunk number 13: 
###################################################
#line 221 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpFhU4ge/R.INSTALL278e6b04/affyILM/inst/doc/affyILM.Rnw"
res2_1 <- result2files["AFFX-r2-Ec-bioD-5_at"]
res2_1
res2_2 <- result2files[c("AFFX-r2-Ec-bioD-5_at","207218_at")]
res2_2


###################################################
### chunk number 14: 
###################################################
#line 233 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpFhU4ge/R.INSTALL278e6b04/affyILM/inst/doc/affyILM.Rnw"
plotIntens(result2files,"AFFX-r2-Ec-bioD-5_at","HG-Focus-1-121502.CEL")
